==> activity-center-api-0.7.6.1.wb5-20170804.055924-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/AlipayOrderDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.util.Date;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * Created by wubo on 2017/7/10.
 */
public class AlipayOrderDto extends BaseDto {

    private static final long serialVersionUID = 1L;
    private Long              id;

    /**
     * 推啊订单号
     */
    private String            orderId;

    /**
     * alipay订单id
     */
    private String            aliOrderId;

    /**
     * 媒体id
     */
    private Long              appId;

    /**
     * 广告位id
     */
    private Long              slotId;

    /**
     * 设备id
     */
    private String            deviceId;

    /**
     * 活动id
     */
    private Long              activityId;

    /**
     * 活动类型
     */
    private Integer           activityType;

    /**
     * 奖项id
     */
    private Long              prizeId;

    /**
     * 支付活动类型
     */
    private Integer           alipayType;

    /**
     * 支付宝账号
     */
    private String            aliAccount;

    /**
     * 支付宝姓名
     */
    private String            aliName;

    /**
     * 中奖金额
     */
    private Integer           awardAmount;

    /**
     * 订单状态
     */
    private Integer           status;

    /**
     * 返回code
     */
    private String            resultCode;

    /**
     * 返回信息
     */
    private String            resultMsg;

    /**
     * 奖品类型
     */
    private String            prizeType;

    /**
     * 奖品类型str
     */
    private String            prizeTypeStr;

    private Date              gmtCreate;

    private Date              gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getAliOrderId() {
        return aliOrderId;
    }

    public void setAliOrderId(String aliOrderId) {
        this.aliOrderId = aliOrderId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public String getAliAccount() {
        return aliAccount;
    }

    public void setAliAccount(String aliAccount) {
        this.aliAccount = aliAccount;
    }

    public String getAliName() {
        return aliName;
    }

    public void setAliName(String aliName) {
        this.aliName = aliName;
    }

    public Integer getAwardAmount() {
        return awardAmount;
    }

    public void setAwardAmount(Integer awardAmount) {
        this.awardAmount = awardAmount;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResultCode() {
        return resultCode;
    }

    public void setResultCode(String resultCode) {
        this.resultCode = resultCode;
    }

    public String getResultMsg() {
        return resultMsg;
    }

    public void setResultMsg(String resultMsg) {
        this.resultMsg = resultMsg;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeTypeStr() {
        return prizeTypeStr;
    }

    public void setPrizeTypeStr(String prizeTypeStr) {
        this.prizeTypeStr = prizeTypeStr;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-0.8.0.3-wb3-20171116.072811-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/AlipayOrderDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.util.Date;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * Created by wubo on 2017/7/10.
 */
public class AlipayOrderDto extends BaseDto {

    private static final long serialVersionUID = 1L;
    private Long id;

    /**
     * 推啊订单号
     */
    private String orderId;

    /**
     * alipay订单id
     */
    private String aliOrderId;

    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * 设备id
     */
    private String deviceId;

    /**
     * 活动id
     */
    private Long activityId;

    /**
     * 活动类型
     */
    private Integer activityType;

    /**
     * 奖项id
     */
    private Long prizeId;

    /**
     * 支付活动类型
     */
    private Integer alipayType;

    /**
     * 支付宝账号
     */
    private String aliAccount;

    /**
     * 支付宝姓名
     */
    private String aliName;

    /**
     * 中奖金额
     */
    private Integer awardAmount;

    /**
     * 订单状态
     */
    private Integer status;

    /**
     * 返回code
     */
    private String resultCode;

    /**
     * 返回信息
     */
    private String resultMsg;

    /**
     * 奖品类型
     */
    private String prizeType;

    /**
     * 奖品类型str
     */
    private String prizeTypeStr;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 奖品名称
     */
    private String prizeTitle;
    /**
     * 收获地址
     */
    private String shippingAddress;
    /**
     * 备注
     */
    private String remark;

    /**
     * 快递单号
     */
    private String expressNumber;
    /**
     * 快递公司
     */
    private String express;

    /**
     * 券码(扩展信息)
     */
    private String code;

    /**
     * 券密码(扩展信息)
     */
    private String password;
    
    /**
     * 奖品价值
     */
    private String prizeWorth;

    public String getPrizeTitle() {
        return prizeTitle;
    }

    public void setPrizeTitle(String prizeTitle) {
        this.prizeTitle = prizeTitle;
    }

    public String getShippingAddress() {
        return shippingAddress;
    }

    public void setShippingAddress(String shippingAddress) {
        this.shippingAddress = shippingAddress;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getExpressNumber() {
        return expressNumber;
    }

    public void setExpressNumber(String expressNumber) {
        this.expressNumber = expressNumber;
    }

    public String getExpress() {
        return express;
    }

    public void setExpress(String express) {
        this.express = express;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getAliOrderId() {
        return aliOrderId;
    }

    public void setAliOrderId(String aliOrderId) {
        this.aliOrderId = aliOrderId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public String getAliAccount() {
        return aliAccount;
    }

    public void setAliAccount(String aliAccount) {
        this.aliAccount = aliAccount;
    }

    public String getAliName() {
        return aliName;
    }

    public void setAliName(String aliName) {
        this.aliName = aliName;
    }

    public Integer getAwardAmount() {
        return awardAmount;
    }

    public void setAwardAmount(Integer awardAmount) {
        this.awardAmount = awardAmount;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResultCode() {
        return resultCode;
    }

    public void setResultCode(String resultCode) {
        this.resultCode = resultCode;
    }

    public String getResultMsg() {
        return resultMsg;
    }

    public void setResultMsg(String resultMsg) {
        this.resultMsg = resultMsg;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeTypeStr() {
        return prizeTypeStr;
    }

    public void setPrizeTypeStr(String prizeTypeStr) {
        this.prizeTypeStr = prizeTypeStr;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getPrizeWorth() {
        return prizeWorth;
    }

    public void setPrizeWorth(String prizeWorth) {
        this.prizeWorth = prizeWorth;
    }
}
